doapfiend.plugins.text.DoapPrinter

Package doapfiend :: Package plugins :: Module text :: Class DoapPrinter |
[hide private]
[frames] | no frames]

# Class DoapPrinter

source code

    object --+
             |
            DoapPrinter

Prints DOAP in human readable text

Instance Methods | [hide private]
__init__(self, doap, brief=False, color=False) Initialize attributes | source code
write(self, text) Write to DOAP output file object | source code
unicode |
print_doap(self) Serialize DOAP in human readable text, optionally colorized | source code
print_misc(self) Prints basic DOAP metadata | source code
print_repos(self) Prints DOAP repository metadata | source code
print_releases(self) Print DOAP package release metadata | source code
print_people(self) Print all people involved in the project | source code
None |
print_field(self, name) Print a DOAP element | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, doap, brief=False, color=False) (Constructor) | source code
Initialize attributes Overrides: object.__init__

### print_doap(self) | source code
Serialize DOAP in human readable text, optionally colorized Returns: unicode DOAP as plain text

### print_field(self, name) | source code
Print a DOAP element Parameters: `name` (string, list or RDFSubject) - A misc DOAP element Returns: None Nothing